@@ -8,10 +8,20 @@
 setMethod("buffer.dist", signature(observations = "SpatialPointsDataFrame", predictionDomain = "SpatialPixelsDataFrame"), function(observations, predictionDomain, classes, width, ...){
   if(missing(width)){ width <- sqrt(areaSpatialGrid(predictionDomain)) }
   if(!length(classes)==length(observations)){ stop("Length of 'observations' and 'classes' does not match.") }
+  ## remove classes without any points:
+  xg = summary(classes, maxsum=length(levels(classes)))
+  selg.levs = attr(xg, "names")[xg > 1]
+  if(length(selg.levs)<length(levels(classes))){
+    fclasses <- as.factor(classes)
+    fclasses[which(!fclasses %in% selg.levs)] <- NA
+    classes <- droplevels(fclasses)
+  }
+  ## derive buffer distances
   s <- list(NULL)
   for(i in 1:length(levels(classes))){
-    s[[i]] <- distance(rasterize(observations[which(classes==levels(classes)[i]),1]@coords, y=raster(predictionDomain)), width=width, ...)
+    s[[i]] <- raster::distance(rasterize(observations[which(classes==levels(classes)[i]),1]@coords, y=raster(predictionDomain)), width=width, ...)
   }
+  s <- s[sapply(s, function(x){!is.null(x)})]
   s <- brick(s)
   s <- as(s, "SpatialPixelsDataFrame")
   s <- s[predictionDomain@grid.index,]
